<script setup lang="ts">
import { useVbenDrawer, type VbenFormProps } from '@vben/common-ui';

import { Space } from 'ant-design-vue';

import { useVbenVxeGrid, type VxeGridProps, vxeSortEvent } from '#/adapter/vxe-table';
import { listFixBorrow } from '#/api/eims/fixture-borrow';
import { customColumns as columns, querySchema } from '#/views/eims/fixture-borrow/data';

const [BasicDrawer, drawerApi] = useVbenDrawer({
  onCancel: handleCancel,
  onConfirm: handleConfirm,
  async onOpenChange(isOpen) {
    if (!isOpen) {
      return null;
    }
  }
});

const formOptions: VbenFormProps = {
  commonConfig: {
    labelWidth: 80,
    componentProps: {
      allowClear: true
    }
  },
  collapsed: true,
  schema: querySchema(),
  wrapperClass: 'grid-cols-1 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4',
  handleReset: async () => {
    // eslint-disable-next-line no-use-before-define
    const { formApi, reload } = tableApi;
    await formApi.resetForm();
    const formValues = formApi.form.values;
    formApi.setLatestSubmissionValues(formValues);
    await reload(formValues);
  },
  // 日期选择格式化
  fieldMappingTime: []
};

const gridOptions: VxeGridProps = {
  checkboxConfig: {
    // 高亮
    highlight: true,
    // 翻页时保留选中状态
    reserve: true
    // 点击行选中
    // trigger: 'row'
  },
  columns,
  height: 'auto',
  keepSource: true,
  pagerConfig: {},
  toolbarConfig: {
    enabled: false
  },
  formConfig: {
    enabled: false
  },
  proxyConfig: {
    ajax: {
      query: async ({ page }, formValues = {}) => {
        const { fixtureId } = drawerApi.getData() as { fixtureId?: number | string };
        return await listFixBorrow({
          fixtureId,
          pageNum: page.currentPage,
          pageSize: page.pageSize,
          ...formValues
        });
      }
    }
  },
  rowConfig: {
    isHover: true,
    keyField: 'id'
  },
  sortConfig: {
    // 远程排序
    remote: true,
    // 支持多字段排序 默认关闭
    multiple: true
  },
  id: 'fixture-borrow-list-index'
};
const [BasicTable, tableApi] = useVbenVxeGrid({
  gridOptions,
  gridEvents: {
    sortChange: (sortParams) => vxeSortEvent(tableApi, sortParams)
  }
});

async function handleCancel() {
  drawerApi.close();
}

async function handleConfirm() {
  try {
    drawerApi.drawerLoading(true);

    await handleCancel();
  } catch (error) {
    console.error(error);
  } finally {
    drawerApi.drawerLoading(false);
  }
}
</script>

<template>
  <BasicDrawer :close-on-click-modal="false" class="w-[800px]" title="借用记录">
    <BasicTable class="flex-1 overflow-hidden" table-title="借用记录">
      <template #fixtureName="{ row }">
        <Space>
          <span>{{ row.fixtureName }}</span>
        </Space>
      </template>

      <template #action="{ row }"> </template>
    </BasicTable>
  </BasicDrawer>
</template>

<style scoped></style>
